@@ -271,12 +271,6 @@ class SegmentationDataset:
         # check whether polygon data has been set and matches the names in the source imagery
         self.check_polygons()
 
-        # check whether the labels_path directory exists
-        if isdir(self.labels_path):
-            pass
-        else:
-            mkdir(self.labels_path)
-
         # loop through the shapefiles in the polygons directory
         for filename in self.data_names:
             fname = splitext(filename)[0]
@@ -430,12 +424,12 @@ class SegmentationDataset:
         # create the tf.data.Dataset object
         if perform_one_hot:
             output_signature = (
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.int8),
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, n_classes), dtype=tf.int8))
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.float32),
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, n_classes), dtype=tf.float32))
         else:
             output_signature = (
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.int8),
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, 1), dtype=tf.int8))
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.float32),
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, 1), dtype=tf.float32))
 
         tf_ds = tf.data.Dataset.from_generator(
             generator,
