@@ -162,8 +162,7 @@ class VGG19Unet(SegmentationModel):
         self.n_filters = n_filters
         self.dropout_rate = dropout_rate
 
-    def compile_model(self, loss: list = ['sparse_categorical_crossentropy'],
-                      loss_weights: list = [1.0],
+    def compile_model(self, loss: tf.keras.losses.Loss = 'sparse_categorical_crossentropy',
                       learning_rate: float = 0.001,
                       rescale_factor: float = 1 / 255,
                       include_residual: bool = False,
@@ -175,7 +174,6 @@ class VGG19Unet(SegmentationModel):
 
         Args:
             loss: the loss function to use during training;
-            loss_weights: the weights to apply to each loss;
             learning_rate: the starting learning rate for the Adam optimizer;
             rescale_factor: the factor by which to rescale the input tensor;
             include_residual: incorporate a residual connection into each convolutional block;
@@ -305,7 +303,6 @@ class VGG19Unet(SegmentationModel):
 
         # compile the model
         model.compile(loss=loss,
-                      loss_weights=loss_weights,
                       optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate,
                                                          clipnorm=1.0))
 
@@ -328,8 +325,7 @@ class Unet(SegmentationModel):
         self.n_filters = n_filters
         self.dropout_rate = dropout_rate
 
-    def compile_model(self, loss: list =['sparse_categorical_crossentropy'],
-                      loss_weights: list = [1.0],
+    def compile_model(self, loss: tf.keras.losses.Loss = 'sparse_categorical_crossentropy',
                       learning_rate: float = 0.001,
                       rescale_factor: float = 1 / 255,
                       include_residual: bool = False,
@@ -340,7 +336,6 @@ class Unet(SegmentationModel):
 
         Args:
             loss: the loss function to use during training;
-            loss_weights: the weights to apply to each loss;
             learning_rate: the starting learning rate for the Adam optimizer;
             rescale_factor: the factor by which to rescale the input tensor;
             include_residual: include residual connections in each level;
@@ -433,15 +428,13 @@ class Unet(SegmentationModel):
         outputs = Conv2D(filters=self.n_classes,
                          kernel_size=(1, 1),
                          padding='same',
-                         activation='softmax')(u0_out)
+                         activation='sigmoid')(u0_out)
 
         # create the model object
         model = tf.keras.Model(inputs=inputs, outputs=outputs)
 
         # compile the model
         model.compile(loss=loss,
-                      loss_weights=loss_weights,
-                      optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate,
-                                                         clipnorm=1.0))
+                      optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate))
 
         self.model = model
